## File "PloneInstaller/Scripts/dependencies_setup.py"
## -*- coding: utf-8 -*-
# 
# This file use the configuration described in "Configs/dependencies.py" to setup this product dependencies.

from types import StringTypes
from Products.CMFCore.utils import getToolByName



#########################################################################################################
########################################## Public methods ###############################################
#########################################################################################################



def dependencies_install(self, out, project_name, globals):
    try:
      dependencies_module = __import__("Configs.dependencies",
                                            globals, locals(),
                                           [
                                              'DEPENDENCIES',
                                            ]
                                          )

      out.openSection("Configs.dependencies setup")

      # Dependencies configuration
      dependencies = getattr(dependencies_module, 'DEPENDENCIES', None)
      if dependencies != None:
        _installDependencies(self, out, dependencies)

      out.closeSection("Configs.dependencies setup")

    except ImportError:
        out.info("Configs.dependencies setup : Noting to be done.")



##---------------------------------------------------------------------------



def dependencies_remove(self, out, project_name, globals):
    try:
      dependencies_module = __import__("Configs.dependencies",
                                            globals, locals(),
                                           [
                                              'DEPENDENCIES',
                                            ]
                                          )

      out.openSection("Configs.dependencies removal")

      # Dependencies configuration
      dependencies = getattr(dependencies_module, 'DEPENDENCIES', None)
      if dependencies != None:
        _removeDependencies(self, out, dependencies)

      out.closeSection("Configs.dependencies removal")

    except ImportError:
        out.info("Configs.dependencies removal : Noting to be done.")



#########################################################################################################
######################################## Install functions ##############################################
#########################################################################################################



## _installDependencies
# 
# Setup dependencies configuration
def _installDependencies(self, out, dependencies):
    errorFlag = False

    out.openSubsection("Dependencies setup")

    try: # Check for quick installer tool existance
        quickinstaller_tool = getToolByName(self, 'portal_quickinstaller')
    except AttributeError:
        out.error("'portal_quickinstaller' tool not found !")
    else:

        for dependency in dependencies:

            if type(dependency) in StringTypes:
                dependency = { 'name' : dependency, 'reinstall' : False }

            try:
                if quickinstaller_tool.isProductInstalled(dependency['name']) and dependency['reinstall']:
                    quickinstaller_tool.reinstallProducts(dependency['name'])
                    out.info("Reinstalled dependency '%s'." % dependency['name'])
                else:
                    quickinstaller_tool.installProduct(dependency['name'])
                    out.info("Installed dependency '%s'." % dependency['name'])
            except Exception, e:
                errorFlag = True
                out.error("failed to install dependency '%s'. (Error message : %s)" % (dependency['name'], str(e)) )

        # INFO We commit the transaction to avoid already installed product uninstallation.
        # INFO very bad ?
        get_transaction().commit(1)

        if not errorFlag:
            out.success("Completed dependencies setup without errors.")

    out.closeSubsection("Dependencies setup")



#########################################################################################################
######################################### Remove functions ##############################################
#########################################################################################################



## _removeDependencies
# 
# Remove dependencies configuration.
# TODO : Create a remove dependencies method.
def _removeDependencies(self, out, dependencies):

    out.openSubsection("Dependencies removal")

    try: # Check for quick installer tool existance
        quickinstaller_tool = getToolByName(self, 'portal_quickinstaller')
    except AttributeError:
        out.error("'portal_quickinstaller' tool not found !")
    else:
#        try:
#            quickinstaller_tool.uninstallProducts(products = dependencies)
#            out.success("Completed dependencies setup without errors.")
#        except Exception, e:
#            out.error("failed dependencies removal. (Error message : %s)" % str(e))
        out.info("Dependencies can not be removed.")

    out.closeSubsection("Dependencies removal")



#########################################################################################################
######################################### Private functions #############################################
#########################################################################################################

